DBSCAN: DBSCAN clustering method

DBSCANR Documentation

DBSCAN clustering method

Description

Run the DBSCAN algorithm for clustering.

Usage

DBSCAN(d, minpts = 5, eps = NULL, graph = FALSE, ...)

Arguments

d

The dataset (matrix or data.frame).

minpts

Reachability minimum no. of points.

eps

Reachability distance. If NULL (the default), it is set to the knee of the sorted minpts-distance curve – the construction distplot invites you to do by eye – and the value used is reported in a message. This is only a starting point: eps is the parameter DBSCAN is most sensitive to, and it is worth looking at distplot (minpts, d) before settling on one.

graph

A logical indicating whether or not a graphic should be plotted (the minpts-distance curve used to choose eps, when eps is not given).

...

Other parameters.

Value

A clustering model obtained by DBSCAN.

See Also

dbscan, dbs-class, distplot, predict.dbs

Examples

require (datasets)
data (iris)
DBSCAN (iris [, -5], minpts = 5, eps = 1)

fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.