GBREG: Regression using Gradient Boosting

GBREGR Documentation

Regression using Gradient Boosting

Description

This function builds a regression model using Gradient Boosting. It is the regression counterpart of GRADIENTBOOSTING, which classifies.

Usage

GBREG(
  x,
  y,
  ntree = 500,
  learningrate = 0.3,
  tune = FALSE,
  methodparameters = NULL,
  graph = FALSE,
  seed = NULL,
  ...
)

Arguments

x

Predictor values of the training set, as a matrix or data.frame.

y

Target values of the training set (a numeric vector).

ntree

The number of trees in the ensemble.

learningrate

The learning rate (between 0 and 1).

tune

If true, the function returns parameters instead of a classification model.

methodparameters

Present for interface consistency with performance (which always passes it when fitting a model). Currently unused: GBREG does not yet implement hyperparameter tuning.

graph

Present for interface consistency with performance (which always passes it when fitting a model). Currently unused: GBREG does not produce a plot.

seed

A specified seed for random number generation (row/column subsampling, if used via ...).

...

Other parameters, passed to xgboost.

Value

The regression model.

See Also

GRADIENTBOOSTING, LINREG, SVR, xgboost

Examples


require (datasets)
data (trees)
d = splitdata (trees, 3)
model = GBREG (d$train.x, d$train.y)
evaluation (predict (model, d$test.x), d$test.y)


fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.