SPECTRAL: Spectral clustering method

SPECTRALR Documentation

Spectral clustering method

Description

Run a Spectral clustering algorithm.

Usage

SPECTRAL(d, k, sigma = 1, graph = FALSE, seed = NULL, ...)

Arguments

d

The dataset (matrix or data.frame).

k

The number of cluster.

sigma

Width of the gaussian used to build the affinity matrix.

graph

A logical indicating whether or not a graphic should be plotted (projection on the spectral space of the affinity matrix).

seed

A specified seed for random number generation (final k-means step).

...

Other parameters.

See Also

spectral-class

Examples


require (datasets)
data (iris)
SPECTRAL (iris [, -5], k = 3)


fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.