augmentation: Duplicate and add noise to a dataset

augmentationR Documentation

Duplicate and add noise to a dataset

Description

This function is a data augmentation technique. It duplicates rows and add gaussian noise to the duplicates.

Usage

augmentation(dataset, target, n = 5, sigma = 0.1, seed = NULL)

Arguments

dataset

The dataset to be split (data.frame or matrix).

target

The column index (numeric) or column name (character) of the target variable (class label or response variable).

n

The scaling factor (as an integer value): the output contains n times the original dataset (the original rows, plus n - 1 noisy copies).

sigma

The baseline variance for the noise generation.

seed

A specified seed for random number generation.

Value

An augmented dataset.

Examples

require (datasets)
data (iris)
d = augmentation (iris, 5)
summary (iris)
summary (d)
# 'target' can also be given as a column name
d = augmentation (iris, "Species")

fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.