| capitals | R Documentation |
A small corpus of English sentences about France, Germany and their capitals.
It is deliberately tiny, so that the examples of the text mining functions run in a moment;
a real corpus is loaded with loadtext.
capitals
A character vector of 30 sentences, lowercase and free of punctuation.
Alexandre Blansché alexandre.blansche@univ-lorraine.fr
getvocab, vectorize.docs, vectorize.words,
loadtext
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.