cda-class: Canonical Disciminant Analysis model

cda-classR Documentation

Canonical Disciminant Analysis model

Description

This class contains the classification model obtained by the CDA method.

Details

Objects of this class are plain lists with the following components:

proj

The projection of the dataset into the canonical base. A data.frame.

transform

The transformation matrix between. A matrix.

centers

Coordinates of the class centers. A matrix.

within

The intra-class covariance matrix. A matrix.

eig

One row per canonical axis and four columns: the eigenvalue (of V^{-1}B, i.e. the squared canonical correlation, between 0 and 1), its percentage of variance (share of the trace) and the cumulative one, and the discriminant power – the share of the trace of W^{-1}B, which is what lda and most other software call the proportion of trace. A matrix, or a named vector when there is a single axis.

dim

The number of dimensions of the canonical base (numeric value).

nb.classes

The number of clusters (numeric value).

train

The training set (description). A data.frame.

labels

Class labels of the training set. Either a factor or an integer vector.

model

The prediction model.

See Also

CDA, plot.cda, predict.cda


fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.