powered by
Close the graphics device driver
closegraphics(export = fdm2id.globals$export)
If given, explicitly overrides the global export toggle set by toggleexport for this call only (TRUE closes the device, FALSE is a no-op). By default, the global toggle is used, so existing code is unaffected.
toggleexport
TRUE
FALSE
exportgraphics, toggleexport, dev.off
exportgraphics
dev.off
if (FALSE) { data (iris) exportgraphics ("export.pdf") plotdata (iris [, -5], iris [, 5]) closegraphics() # Explicit override, ignoring the global toggle: closegraphics (export = TRUE) }
Run the code above in your browser using DataLab