data.gauss: Gaussian mixture dataset

data.gaussR Documentation

Gaussian mixture dataset

Description

Generate a random multidimentional gaussian mixture.

Usage

data.gauss(
  n = 1000,
  k = 2,
  prob = rep(1/k, k),
  mu = cbind(rep(0, k), seq(from = 0, by = 3, length.out = k)),
  cov = rep(list(matrix(c(6, 0.9, 0.9, 0.3), ncol = 2, nrow = 2)), k),
  levels = NULL,
  graph = FALSE,
  seed = NULL
)

Arguments

n

Number of observations.

k

The number of classes.

prob

The a priori probability of each class.

mu

The means of the gaussian distributions.

cov

The covariance of the gaussian distributions.

levels

Name of each class.

graph

Whether the generated dataset is plotted. FALSE by default, as everywhere else in the package: a generator has to be callable in a loop or a report without piling up graphics devices.

seed

A specified seed for random number generation.

Value

A randomly generated dataset.

See Also

data.diag, data.parabol, data.target2, data.twomoons, data.xor

Examples

data.gauss (graph = TRUE)

fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.