data.target1: Target1 dataset

data.target1R Documentation

Target1 dataset

Description

Generate a random dataset shaped like a target.

Usage

data.target1(
  r = 1:3,
  n = 200,
  sigma = 0.1,
  levels = NULL,
  graph = FALSE,
  seed = NULL
)

Arguments

r

Radius of each class.

n

Number of observations in each class.

sigma

Variance in each class.

levels

Name of each class.

graph

Whether the generated dataset is plotted. FALSE by default, as everywhere else in the package: a generator has to be callable in a loop or a report without piling up graphics devices.

seed

A specified seed for random number generation.

Value

A randomly generated dataset.

See Also

data.diag, data.parabol, data.target2, data.twomoons, data.xor

Examples

data.target1 (graph = TRUE)

fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.