data.target2: Target2 dataset

data.target2R Documentation

Target2 dataset

Description

Generate a random dataset shaped like a target.

Usage

data.target2(
  minr = c(0, 2),
  maxr = minr + 1,
  initn = 1000,
  levels = NULL,
  graph = FALSE,
  seed = NULL
)

Arguments

minr

Minimum radius of each class.

maxr

Maximum radius of each class.

initn

Number of observations at the beginning of the generation process.

levels

Name of each class.

graph

Whether the generated dataset is plotted. FALSE by default, as everywhere else in the package: a generator has to be callable in a loop or a report without piling up graphics devices.

seed

A specified seed for random number generation.

Value

A randomly generated dataset.

See Also

data.diag, data.parabol, data.target1, data.twomoons, data.xor

Examples

data.target2 (graph = TRUE)

fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.