dataset-class: Training set and test set

dataset-classR Documentation

Training set and test set

Description

This class contains a dataset divided into four parts: the training set and test set, description and class labels.

Details

Objects of this class are plain lists with the following components:

train.x

the training set (description), as a data.frame or a matrix.

train.y

the training set (target), as a vector or a factor.

test.x

the training set (description), as a data.frame or a matrix.

test.y

the training set (target), as a vector or a factor.

See Also

splitdata


fdm2id documentation built on Sept. 4, 2026, 5:07 p.m.