dbs-class: DBSCAN model

dbs-classR Documentation

DBSCAN model

Description

This class contains the model obtained by the DBSCAN method.

Details

Objects of this class are plain lists with the following components:

cluster

A vector of integers indicating the cluster to which each point is allocated.

eps

Reachability distance (parameter).

MinPts

Reachability minimum no. of points (parameter).

isseed

A logical vector indicating whether a point is a seed (not border, not noise).

data

The dataset that has been used to fit the map (as a matrix).

See Also

DBSCAN


fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.