eucalyptus: Eucalyptus dataset

eucalyptusR Documentation

Eucalyptus dataset

Description

Measuring the height of a tree is not an easy task. Is it possible to estimate the height as a function of the circumference of the trunk?

Usage

eucalyptus

Format

The dataset has 1429 instances (eucalyptus trees) with 2 measurements: the height and the circumference.

http://www.cmap.polytechnique.fr/~lepennec/en/teaching/


fdm2id documentation built on Sept. 4, 2026, 5:07 p.m.