factorial-class: Factorial analysis results

factorial-classR Documentation

Factorial analysis results

Description

This class contains the result of a factorial analysis, as obtained by CA, MCA or PCA.

Details

Objects of this class are the objects returned by the corresponding FactoMineR functions (CA, MCA and PCA), with the extra class factorial prepended so that plot.factorial can provide a uniform plotting interface. The second class ("ca", "mca" or "pca") records which analysis was performed.

See Also

CA, MCA, PCA, plot.factorial


fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.