intern.dunn: Clustering evaluation through Dunn's index

intern.dunnR Documentation

Clustering evaluation through Dunn's index

Description

Evaluation a clustering algorithm according to Dunn's index.

Usage

intern.dunn(clus, d, type = c("global", "cluster"))

Arguments

clus

The extracted clusters.

d

The dataset.

type

Indicates whether a "global" or a "cluster"-wise evaluation should be used. The per-cluster values are the terms the global index is the minimum of: each cluster's distance to the nearest other one, over the largest diameter of the partition.

Value

The evaluation of the clustering.

See Also

intern, intern.interclass, intern.intraclass

Examples

require (datasets)
data (iris)
km = KMEANS (iris [, -5], k = 3)
intern.dunn (km$cluster, iris [, -5])
intern.dunn (km$cluster, iris [, -5], type = "cluster")

fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.