knn-class: K Nearest Neighbours model

knn-classR Documentation

K Nearest Neighbours model

Description

This class contains the classification model obtained by the k-NN method.

Details

Objects of this class are plain lists with the following components:

train

The training set (description). A data.frame.

labels

Class labels of the training set. Either a factor or an integer vector.

k

The k parameter.

See Also

KNN, predict.knn


fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.