leverageplot: Plot the leverage points of a linear regression model

leverageplotR Documentation

Plot the leverage points of a linear regression model

Description

Plot the leverage points of a linear regression model.

Usage

leverageplot(model, index = NULL, labels = NULL)

Arguments

model

The model to be plotted.

index

The index of the variable used for the x-axis.

labels

The labels of the instances.

Examples

require (datasets)
data (trees)
model = LINREG (trees [, -3], trees [, 3])
leverageplot (model)

fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.