meanshift-class: MeanShift model

meanshift-classR Documentation

MeanShift model

Description

This class contains the model obtained by the MEANSHIFT method.

Details

Objects of this class are plain lists with the following components:

cluster

A vector of integers indicating the cluster to which each point is allocated.

value

A vector or matrix containing the location of the classified local maxima in the support.

data

The leaning set.

kernel

A string indicating the kernel associated with the kernel density estimate that the mean shift is optimizing over.

bandwidth

Used in the kernel density estimate for steepest ascent classification.

alpha

A scalar tuning parameter for normal kernels.

iterations

The number of iterations to perform mean shift.

epsilon

A scalar used to determine when to terminate the iteration of an individual query point.

epsilonCluster

A scalar used to determine the minimum distance between distinct clusters.

See Also

MEANSHIFT


fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.