model-class: Generic classification or regression model

model-classR Documentation

Generic classification or regression model

Description

This is a wrapper class containing the classification model obtained by any classification or regression method.

Details

Objects of this class are plain lists with the following components:

model

The wrapped model.

method

The name of the method.

See Also

predict.model, predict


fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.