| params-class | R Documentation |
This class contains main parameters for various learning methods.
Objects of this class are plain lists with the following components:
decayThe decay parameter.
hiddenThe number of hidden nodes.
epsilonThe epsilon parameter.
gammaThe gamma parameter.
costThe cost parameter.
MLP, MLPREG, SVM, SVR
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.