plot.cda: Plot function for cda-class

plot.cdaR Documentation

Plot function for cda-class

Description

Plot the learning set (and test set) on the canonical axes obtained by Canonical Discriminant Analysis (function CDA).

Usage

## S3 method for class 'cda'
plot(x, newdata = NULL, axes = 1:2, legendpos = "topleft", ...)

Arguments

x

The classification model (object of class cda-class).

newdata

The test set (matrix or data.frame).

axes

The canonical axes to be printed (numeric vector). Ignored when there is only one, which is what two classes give: the axis is then drawn against the observation index, and the class means as horizontal lines.

legendpos

Position of the legend, as in plotdata.

...

Other parameters, passed to the underlying plot.

See Also

CDA, predict.cda, cda-class

Examples

require (datasets)
data (iris)
model = CDA (iris [, -5], iris [, 5])
plot (model)

fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.