plotcloud: Plot word cloud

plotcloudR Documentation

Plot word cloud

Description

Plot a word cloud based on the word frequencies in the documents.

Usage

plotcloud(corpus, k = NULL, stopwords = "en", ...)

Arguments

corpus

The corpus of documents (a vector of characters) or the vocabulary of the documents (result of function getvocab).

k

A categorical variable (vector or factor).

stopwords

The language whose stop words are removed ("en", ...), or NULL to keep them. A list of words of your own goes to excludewords.

...

Other parameters.

See Also

plotzipf, getvocab, wordcloud

Examples

data (capitals)
plotcloud (capitals)
vocab = getvocab (capitals, mincount = 1, lang = NULL, stopwords = "en")
plotcloud (vocab)

fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.