print.dbs: Print a DBSCAN clustering

print.dbsR Documentation

Print a DBSCAN clustering

Description

Prints the number of clusters found, their sizes, the observations left as noise, and the two parameters used – instead of dumping the underlying list.

Usage

## S3 method for class 'dbs'
print(x, ...)

Arguments

x

The clustering (object of class dbs-class, created by DBSCAN).

...

Other parameters.

See Also

dbs-class, DBSCAN

Examples

require (datasets)
data (iris)
DBSCAN (iris [, -5], minpts = 5, eps = 0.65)

fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.