print.model: Print a classification or regression model

print.modelR Documentation

Print a classification or regression model

Description

Prints a short description of the model – the method it was obtained with, and the size of the data it was fitted on – instead of dumping the underlying list. Use summary (model) for the full detail of the wrapped model.

Usage

## S3 method for class 'model'
print(x, ...)

Arguments

x

The model to be printed (object of class model-class).

...

Other parameters.

See Also

model-class, summary.model, predict.model

Examples

require (datasets)
data (iris)
NB (iris [, -5], iris [, 5])

fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.