print.som: Print a self-organising map

print.somR Documentation

Print a self-organising map

Description

Prints the size of the map, how many of its units are actually used, and the dataset it was fitted on.

Usage

## S3 method for class 'som'
print(x, ...)

Arguments

x

The map (object of class som-class, created by SOM).

...

Other parameters.

See Also

som-class, SOM

Examples


require (datasets)
data (iris)
SOM (iris [, -5], 4, 4)


fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.