resplot: Plot the studentized residuals of a linear regression model

resplotR Documentation

Plot the studentized residuals of a linear regression model

Description

Plot the studentized residuals of a linear regression model.

Usage

resplot(model, index = NULL, labels = NULL)

Arguments

model

The model to be plotted.

index

The index of the variable used for the x-axis.

labels

The labels of the instances.

Examples

require (datasets)
data (trees)
model = LINREG (trees [, -3], trees [, 3])
resplot (model) # Ordered by index
resplot (model, index = 0) # Ordered by variable "Volume" (dependent variable)
resplot (model, index = 1) # Ordered by variable "Girth" (independent variable)
resplot (model, index = 2) # Ordered by variable "Height" (independent variable)

fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.