Cluster labels of the training set: a numeric vector (0 marking the
observations a density method left as noise), or a factor/character vector, whose
levels are then used to label the legend.
centers
Coordinates of the cluster centers.
labels
Indicates whether or not labels (row names) should be showned on the plot.
ellipses
Indicates whether or not ellipses should be drawned around clusters.
legend
Indicates where the legend is placed on the graphics.