| selection-class | R Documentation |
This class contains the result of feature selection algorithms.
Objects of this class are plain lists with the following components:
selectionA vector of integers indicating the selected features.
featuresThe names of the selected features, when the dataset had column names.
unievalThe evaluation of the features (univariate).
multievalThe evaluation of the selected features (multivariate).
algorithmThe algorithm used to select features.
univariateThe evaluation criterion (univariate).
nbfeaturesThe number of features to be kept.
thresholdThe threshold to decide whether a feature is kept or not.
multivariateThe evaluation criterion (multivariate).
datasetThe dataset described by the selected features only.
modelThe classification model.
FEATURESELECTION, predict.selection, selectfeatures
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.