som-class: Self-Organizing Maps model

som-classR Documentation

Self-Organizing Maps model

Description

This class contains the model obtained by the SOM method.

Details

Objects of this class are plain lists with the following components:

som

An object of class kohonen representing the fitted map.

nodes

A vector of integer indicating the cluster to which each node is allocated.

cluster

A vector of integer indicating the cluster to which each observation is allocated.

data

The dataset that has been used to fit the map (as a matrix).

See Also

plot.som, SOM, som


fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.