spectral-class: Spectral clustering model

spectral-classR Documentation

Spectral clustering model

Description

This class contains the model obtained by Spectral clustering.

Details

Objects of this class are plain lists with the following components:

cluster

A vector of integer indicating the cluster to which each observation is allocated.

proj

The projection of the dataset in the spectral space.

centers

The cluster centers (on the spectral space).

data

The dataset that has been used to fit the model (as a matrix).

See Also

SPECTRAL, predict.spectral


fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.