summary.model: Summary of a classification or regression model

summary.modelR Documentation

Summary of a classification or regression model

Description

Prints the short description of print.model, followed by the summary of the wrapped model itself.

Usage

## S3 method for class 'model'
summary(object, ...)

Arguments

object

The model (object of class model-class).

...

Other parameters, passed to the summary of the wrapped model.

See Also

model-class, print.model

Examples

require (datasets)
data (iris)
summary (NB (iris [, -5], iris [, 5]))

fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.