vectorizer-class: Document vectorization object

vectorizer-classR Documentation

Document vectorization object

Description

This class contains a vectorization model for textual documents.

Details

Objects of this class are plain lists with the following components:

vectorizer

The vectorizer.

transform

The transformation to be applied after vectorization (normalization, TF-IDF).

phrases

The phrase detection method.

tfidf

The TF-IDF transformation.

lsa

The LSA transformation.

tokens

The token from the original document.

See Also

vectorize.docs, query.docs


fdm2id documentation built on Aug. 28, 2026, 9:07 a.m.