Learn R Programming

fdm2id (version 1.0.1)

ADABOOST: Classification using AdaBoost

Description

Ensemble learning, through AdaBoost Algorithm.

Usage

ADABOOST(
  x,
  y,
  learningmethod,
  nsamples = 100,
  fuzzy = FALSE,
  tune = FALSE,
  methodparameters = NULL,
  graph = FALSE,
  seed = NULL,
  ...
)

Value

The classification model.

Arguments

x

The dataset (description/predictors), a matrix or data.frame.

y

The target (class labels or numeric values), a factor or vector.

learningmethod

The boosted method.

nsamples

The number of samplings.

fuzzy

Indicates whether or not fuzzy classification should be used or not.

tune

If true, the function returns parameters instead of a classification model.

methodparameters

Present for interface consistency with performance (which always passes it when fitting a model). Currently unused: ADABOOST does not support reusing pre-tuned parameters (the base learner given as learningmethod is tuned independently on each boosting sample).

graph

Present for interface consistency with performance (which always passes it when fitting a model). Currently unused: ADABOOST does not produce a plot.

seed

A specified seed for random number generation.

...

Other specific parameters for the leaning method.

See Also

BAGGING, predict.boosting

Examples

Run this code
# \donttest{
require (datasets)
data (iris)
ADABOOST (iris [, -5], iris [, 5], NB)
# }

Run the code above in your browser using DataLab