The dataset (description/predictors), a matrix or data.frame.
y
The target (class labels or numeric values), a factor or vector.
learningmethod
The boosted method.
nsamples
The number of samplings.
fuzzy
Indicates whether or not fuzzy classification should be used or not.
tune
If true, the function returns parameters instead of a classification model.
methodparameters
Present for interface consistency with performance
(which always passes it when fitting a model). Currently unused: ADABOOST does not
support reusing pre-tuned parameters (the base learner given as learningmethod is
tuned independently on each boosting sample).
graph
Present for interface consistency with performance (which always
passes it when fitting a model). Currently unused: ADABOOST does not produce a plot.