| GBREG | R Documentation |
This function builds a regression model using Gradient Boosting. It is the regression
counterpart of GRADIENTBOOSTING, which classifies.
GBREG(
x,
y,
ntree = 500,
learningrate = 0.3,
tune = FALSE,
methodparameters = NULL,
graph = FALSE,
seed = NULL,
...
)
x |
Predictor values of the training set, as a |
y |
Target values of the training set (a numeric |
ntree |
The number of trees in the ensemble. |
learningrate |
The learning rate (between 0 and 1). |
tune |
If true, the function returns parameters instead of a classification model. |
methodparameters |
Present for interface consistency with |
graph |
Present for interface consistency with |
seed |
A specified seed for random number generation (row/column subsampling, if used
via |
... |
Other parameters, passed to |
The regression model.
GRADIENTBOOSTING, LINREG, SVR,
xgboost
require (datasets)
data (trees)
d = splitdata (trees, 3)
model = GBREG (d$train.x, d$train.y)
evaluation (predict (model, d$test.x), d$test.y)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.