Predictor values of the training set, as a matrix or data.frame.
y
Target values of the training set (a numeric vector).
ntree
The number of trees in the ensemble.
learningrate
The learning rate (between 0 and 1).
tune
If true, the function returns parameters instead of a classification model.
methodparameters
Present for interface consistency with performance
(which always passes it when fitting a model). Currently unused: GBREG does not yet
implement hyperparameter tuning.
graph
Present for interface consistency with performance (which always
passes it when fitting a model). Currently unused: GBREG does not produce a plot.
seed
A specified seed for random number generation (row/column subsampling, if used
via ...).