Class labels of the training set (vector or factor).
ntree
The number of trees in the forest.
learningrate
The learning rate (between 0 and 1).
tune
If true, the function returns parameters instead of a classification model.
methodparameters
Present for interface consistency with performance
(which always passes it when fitting a model). Currently unused: GRADIENTBOOSTING
does not yet implement hyperparameter tuning.
graph
Present for interface consistency with performance (which always
passes it when fitting a model). Currently unused: GRADIENTBOOSTING does not produce
a plot.
seed
A specified seed for random number generation (row/column subsampling, if used
via ...; xgboost's default parameters are otherwise deterministic, but the seed
is provided for consistency with the rest of the package's API and to cover subsampling
parameters passed through ...).