A string indicating the kernel associated with the kernel density estimate that the mean shift is optimizing over.
bandwidth
Used in the kernel density estimate for steepest ascent classification.
alpha
A scalar tuning parameter for normal kernels.
iterations
The number of iterations to perform mean shift.
epsilon
A scalar used to determine when to terminate the iteration of an individual query point.
epsilonCluster
A scalar used to determine the minimum distance between distinct clusters.
seed
A specified seed for random number generation. The MeanShift algorithm itself is deterministic
given its parameters, but the seed is provided for consistency with the rest of the package's API.