powered by
Run a Spectral clustering algorithm.
SPECTRAL(d, k, sigma = 1, graph = FALSE, seed = NULL, ...)
The dataset (matrix or data.frame).
matrix
data.frame
The number of cluster.
Width of the gaussian used to build the affinity matrix.
A logical indicating whether or not a graphic should be plotted (projection on the spectral space of the affinity matrix).
A specified seed for random number generation (final k-means step).
Other parameters.
spectral-class
# \donttest{ require (datasets) data (iris) SPECTRAL (iris [, -5], k = 3) # }
Run the code above in your browser using DataLab