Learn R Programming

fdm2id (version 1.0.1)

augmentation: Duplicate and add noise to a dataset

Description

This function is a data augmentation technique. It duplicates rows and add gaussian noise to the duplicates.

Usage

augmentation(dataset, target, n = 5, sigma = 0.1, seed = NULL)

Value

An augmented dataset.

Arguments

dataset

The dataset to be split (data.frame or matrix).

target

The column index (numeric) or column name (character) of the target variable (class label or response variable).

n

The scaling factor (as an integer value): the output contains n times the original dataset (the original rows, plus n - 1 noisy copies).

sigma

The baseline variance for the noise generation.

seed

A specified seed for random number generation.

Examples

Run this code
require (datasets)
data (iris)
d = augmentation (iris, 5)
summary (iris)
summary (d)
# 'target' can also be given as a column name
d = augmentation (iris, "Species")

Run the code above in your browser using DataLab