| boosting-class | R Documentation |
This class contains the ensemble of models obtained by a boosting or bagging method
(ADABOOST, BAGGING).
Objects of this class are plain lists with the following components:
modelsList of models.
xThe learning set.
yThe target values.
nsamplesThe number of models that were asked for. Boosting keeps fewer
when it runs out of models better than chance; print.boosting says so.
ADABOOST, BAGGING, predict.boosting
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.