Learn R Programming

fdm2id (version 1.0.1)

boosting-class: Boosting methods model

Description

This class contains the ensemble of models obtained by a boosting or bagging method (ADABOOST, BAGGING).

Arguments

Details

Objects of this class are plain lists with the following components:

models

List of models.

x

The learning set.

y

The target values.

nsamples

The number of models that were asked for. Boosting keeps fewer when it runs out of models better than chance; print.boosting says so.

See Also

ADABOOST, BAGGING, predict.boosting