Learn R Programming

fdm2id (version 1.0.1)

boxclus: Clustering Box Plots

Description

Produce a box-and-whisker plot for clustering results.

Usage

boxclus(d, clusters, legendpos = "topleft", ...)

Arguments

d

The dataset (matrix or data.frame).

clusters

Cluster labels of the training set: a numeric vector (0 marking the observations a density method left as noise), or a factor/character vector, whose levels are then used to label the legend.

legendpos

Position of the legend

...

Other parameters.

See Also

Examples

Run this code
require (datasets)
data (iris)
km = KMEANS (iris [, -5], k = 3)
boxclus (iris [, -5], km$cluster)

Run the code above in your browser using DataLab