This class contains the classification model obtained by the CDA method.
Objects of this class are plain lists with the following components:
projThe projection of the dataset into the canonical base. A data.frame.
transformThe transformation matrix between. A matrix.
centersCoordinates of the class centers. A matrix.
withinThe intra-class covariance matrix. A matrix.
eigOne row per canonical axis and four columns: the eigenvalue
(of \(V^{-1}B\), i.e. the squared canonical correlation, between 0 and 1), its
percentage of variance (share of the trace) and the cumulative one, and
the discriminant power -- the share of the trace of \(W^{-1}B\), which is what
lda and most other software call the proportion of trace. A
matrix, or a named vector when there is a single axis.
dimThe number of dimensions of the canonical base (numeric value).
nb.classesThe number of clusters (numeric value).
trainThe training set (description). A data.frame.
labelsClass labels of the training set. Either a factor or an integer vector.
modelThe prediction model.
CDA, plot.cda, predict.cda