| check.classes | R Documentation |
Internal helper shared by the classification methods that cannot cope with empty classes.
It coerces labels to a factor (which makes it work with character vectors,
for which nlevels returns 0), drops the levels that are not observed (warning about
them) and checks that at least two classes remain.
check.classes(labels, method = "", min.classes = 2)
labels |
Class labels ( |
method |
The name of the calling method, used in the messages (a character string). |
min.classes |
The minimal number of (non-empty) classes required (default: 2). |
labels, as a factor with no empty level.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.