The prediction. This is the first argument, as for every other
evaluation function of the package (evaluation, evaluation.accuracy,
evaluation.precision, ...): passing the ground truth first returns the transposed
matrix.
gt
The ground truth.
norm
Whether or not the confusion matrix is normalized
graph
Whether or not a graphic is displayed.
...
Other parameters, ignored. performance forwards to its evaluation
function the same ... it forwards to the learning method, so a call such as
performance (BAGGING, ..., type = "confusion", learningmethod = CART) would otherwise
fail on the unused learningmethod.