powered by
Generate a random multidimentional gaussian mixture.
data.gauss( n = 1000, k = 2, prob = rep(1/k, k), mu = cbind(rep(0, k), seq(from = 0, by = 3, length.out = k)), cov = rep(list(matrix(c(6, 0.9, 0.9, 0.3), ncol = 2, nrow = 2)), k), levels = NULL, graph = FALSE, seed = NULL )
A randomly generated dataset.
Number of observations.
The number of classes.
The a priori probability of each class.
The means of the gaussian distributions.
The covariance of the gaussian distributions.
Name of each class.
Whether the generated dataset is plotted. FALSE by default, as everywhere else in the package: a generator has to be callable in a loop or a report without piling up graphics devices.
FALSE
A specified seed for random number generation.
data.diag, data.parabol, data.target2, data.twomoons, data.xor
data.diag
data.parabol
data.target2
data.twomoons
data.xor
data.gauss (graph = TRUE)
Run the code above in your browser using DataLab