Learn R Programming

fdm2id (version 1.0.1)

data.target1: Target1 dataset

Description

Generate a random dataset shaped like a target.

Usage

data.target1(
  r = 1:3,
  n = 200,
  sigma = 0.1,
  levels = NULL,
  graph = FALSE,
  seed = NULL
)

Value

A randomly generated dataset.

Arguments

r

Radius of each class.

n

Number of observations in each class.

sigma

Variance in each class.

levels

Name of each class.

graph

Whether the generated dataset is plotted. FALSE by default, as everywhere else in the package: a generator has to be callable in a loop or a report without piling up graphics devices.

seed

A specified seed for random number generation.

See Also

data.diag, data.parabol, data.target2, data.twomoons, data.xor

Examples

Run this code
data.target1 (graph = TRUE)

Run the code above in your browser using DataLab