| dbs-class | R Documentation |
This class contains the model obtained by the DBSCAN method.
Objects of this class are plain lists with the following components:
clusterA vector of integers indicating the cluster to which each point is allocated.
epsReachability distance (parameter).
MinPtsReachability minimum no. of points (parameter).
isseedA logical vector indicating whether a point is a seed (not border, not noise).
dataThe dataset that has been used to fit the map (as a matrix).
DBSCAN
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.