Learn R Programming

fdm2id (version 1.0.1)

evaluation.kappa: Kappa evaluation of classification predictions

Description

Evaluation predictions of a classification model according to Cohen's kappa: the proportion of correct predictions, corrected for the proportion two independent labellings would get right by chance. Class labels being nominal, the kappa is the unweighted one -- every mistake counts the same.

Usage

evaluation.kappa(predictions, gt, ...)

Value

The evaluation of the predictions (numeric value).

Arguments

predictions

The predictions of a classification model (factor or vector).

gt

The ground truth (factor or vector).

...

Other parameters.

See Also

evaluation.accuracy, evaluation.fmeasure, evaluation.fowlkesmallows, evaluation.goodness, evaluation.jaccard, evaluation.kappa, evaluation.precision, evaluation.precision, evaluation.recall, evaluation

Examples

Run this code
require (datasets)
data (iris)
d = splitdata (iris, 5)
model.nb = NB (d$train.x, d$train.y)
pred.nb = predict (model.nb, d$test.x)
evaluation.kappa (pred.nb, d$test.y)

Run the code above in your browser using DataLab