| exportgraphics | R Documentation |
Starts the graphics device driver
exportgraphics(
file,
type = tail(strsplit(file, split = "\\.")[[1]], 1),
export = fdm2id.globals$export,
...
)
file |
A character string giving the name of the file. |
type |
The type of graphics device. Deduced from the file extension by default:
|
export |
If given, explicitly overrides the global export toggle set by |
... |
Other parameters. |
closegraphics, toggleexport, Devices
## Not run:
data (iris)
exportgraphics ("export.pdf")
plotdata (iris [, -5], iris [, 5])
closegraphics()
# Extensions that don't match an R function name directly are now handled:
exportgraphics ("export.eps")
plotdata (iris [, -5], iris [, 5])
closegraphics()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.