| factorial-class | R Documentation |
This class contains the result of a factorial analysis, as obtained by CA,
MCA or PCA.
Objects of this class are the objects returned by the corresponding FactoMineR
functions (CA, MCA and
PCA), with the extra class factorial prepended so that
plot.factorial can provide a uniform plotting interface. The second class
("ca", "mca" or "pca") records which analysis was performed.
CA, MCA, PCA, plot.factorial
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.