| filter.rules | R Documentation |
This function facilitate the selection of a subset from a set of rules.
filter.rules(
rules,
pattern = NULL,
left = pattern,
right = pattern,
removeMatches = FALSE
)
rules |
A set of rules. |
pattern |
A pattern to match (antecedent and consequent): a character string. |
left |
A pattern to match (antecedent only): a character string. |
right |
A pattern to match (consequent only): a character string. |
removeMatches |
A logical indicating whether to remove matching rules ( |
The filtered set of rules.
apriori, subset
require ("arules")
data ("Adult")
r = apriori (Adult, parameter = list (supp = .4, conf = .8))
inspect (filter.rules (r, right = "marital-status="))
# The equivalent call in arules itself
subset (r, subset = rhs %pin% "marital-status=")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.