| frequentwords | R Documentation |
Most frequent words of the corpus.
frequentwords(
corpus,
nb,
mincount = 5,
minphrasecount = NULL,
ngram = 1,
lang = "en",
stopwords = lang,
excludewords = NULL,
removesinglechars = TRUE
)
corpus |
The corpus of documents (a vector of characters) or the vocabulary of the documents (result of function |
nb |
The number of words to be returned. |
mincount |
Minimum word count to be considered as frequent. |
minphrasecount |
Minimum collocation of words count to be considered as frequent. |
ngram |
maximum size of n-grams. |
lang |
The language of the documents (NULL if no stemming). |
stopwords |
The language whose stop words are removed ( |
excludewords |
An optional custom vector of additional words to exclude from the vocabulary (e.g. corpus-specific stop words), on top of (or instead of) the language stopwords given through |
removesinglechars |
Whether single-character tokens are removed during cleanup. |
The most frequent words of the corpus.
getvocab
data (capitals)
frequentwords (capitals, 10, mincount = 2)
vocab = getvocab (capitals, mincount = 2)
frequentwords (vocab, 10)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.