intern.dunn: Clustering evaluation through Dunn's index
Description
Evaluation a clustering algorithm according to Dunn's index.
Usage
intern.dunn(clus, d, type = c("global", "cluster"))
Value
The evaluation of the clustering.
Arguments
clus
The extracted clusters.
d
The dataset.
type
Indicates whether a "global" or a "cluster"-wise evaluation should be used. The
per-cluster values are the terms the global index is the minimum of: each cluster's distance
to the nearest other one, over the largest diameter of the partition.