| model-class | R Documentation |
This is a wrapper class containing the classification model obtained by any classification or regression method.
Objects of this class are plain lists with the following components:
modelThe wrapped model.
methodThe name of the method.
predict.model, predict
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.