Learn R Programming

fdm2id (version 1.0.1)

model-class: Generic classification or regression model

Description

This is a wrapper class containing the classification model obtained by any classification or regression method.

Arguments

Details

Objects of this class are plain lists with the following components:

model

The wrapped model.

method

The name of the method.

See Also

predict.model, predict