powered by
This is a wrapper class containing the classification model obtained by any classification or regression method.
Objects of this class are plain lists with the following components:
model
The wrapped model.
method
The name of the method.
predict.model, predict
predict.model
predict