Learn R Programming

fdm2id (version 1.0.1)

params-class: Learning Parameters

Description

This class contains main parameters for various learning methods.

Arguments

Details

Objects of this class are plain lists with the following components:

decay

The decay parameter.

hidden

The number of hidden nodes.

epsilon

The epsilon parameter.

gamma

The gamma parameter.

cost

The cost parameter.

See Also

MLP, MLPREG, SVM, SVR