Learn R Programming

fdm2id (version 1.0.1)

plotcloud: Plot word cloud

Description

Plot a word cloud based on the word frequencies in the documents.

Usage

plotcloud(corpus, k = NULL, stopwords = "en", ...)

Arguments

corpus

The corpus of documents (a vector of characters) or the vocabulary of the documents (result of function getvocab).

k

A categorical variable (vector or factor).

stopwords

The language whose stop words are removed ("en", ...), or NULL to keep them. A list of words of your own goes to excludewords.

...

Other parameters.

See Also

plotzipf, getvocab, wordcloud

Examples

Run this code
data (capitals)
plotcloud (capitals)
vocab = getvocab (capitals, mincount = 1, lang = NULL, stopwords = "en")
plotcloud (vocab)

Run the code above in your browser using DataLab