powered by
Plot a word cloud based on the word frequencies in the documents.
plotcloud(corpus, k = NULL, stopwords = "en", ...)
The corpus of documents (a vector of characters) or the vocabulary of the documents (result of function getvocab).
getvocab
A categorical variable (vector or factor).
The language whose stop words are removed ("en", ...), or NULL to keep them. A list of words of your own goes to excludewords.
"en"
NULL
excludewords
Other parameters.
plotzipf, getvocab, wordcloud
plotzipf
wordcloud
data (capitals) plotcloud (capitals) vocab = getvocab (capitals, mincount = 1, lang = NULL, stopwords = "en") plotcloud (vocab)
Run the code above in your browser using DataLab