| print.dbs | R Documentation |
Prints the number of clusters found, their sizes, the observations left as noise, and the two parameters used – instead of dumping the underlying list.
## S3 method for class 'dbs'
print(x, ...)
x |
The clustering (object of class |
... |
Other parameters. |
dbs-class, DBSCAN
require (datasets)
data (iris)
DBSCAN (iris [, -5], minpts = 5, eps = 0.65)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.