Learn R Programming

fdm2id (version 1.0.1)

print.dbs: Print a DBSCAN clustering

Description

Prints the number of clusters found, their sizes, the observations left as noise, and the two parameters used -- instead of dumping the underlying list.

Usage

# S3 method for dbs
print(x, ...)

Arguments

x

The clustering (object of class dbs-class, created by DBSCAN).

...

Other parameters.

See Also

dbs-class, DBSCAN

Examples

Run this code
require (datasets)
data (iris)
DBSCAN (iris [, -5], minpts = 5, eps = 0.65)

Run the code above in your browser using DataLab