Learn R Programming

fdm2id (version 1.0.1)

print.model: Print a classification or regression model

Description

Prints a short description of the model -- the method it was obtained with, and the size of the data it was fitted on -- instead of dumping the underlying list. Use summary (model) for the full detail of the wrapped model.

Usage

# S3 method for model
print(x, ...)

Arguments

x

The model to be printed (object of class model-class).

...

Other parameters.

See Also

model-class, summary.model, predict.model

Examples

Run this code
require (datasets)
data (iris)
NB (iris [, -5], iris [, 5])

Run the code above in your browser using DataLab