| print.params | R Documentation |
Prints the hyperparameters a method retained, or says that it has none.
## S3 method for class 'params'
print(x, ...)
x |
The parameters (object of class |
... |
Other parameters. |
params-class, performance
require (datasets)
data (iris)
# A small grid, so that the example stays fast; the defaults search a much larger one.
SVM (iris [, -5], iris [, 5], gamma = 2^(-2:0), cost = 2^(0:2), tune = TRUE)
# A method with nothing to tune says so.
NB (iris [, -5], iris [, 5], tune = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.