| print.som | R Documentation |
Prints the size of the map, how many of its units are actually used, and the dataset it was fitted on.
## S3 method for class 'som'
print(x, ...)
x |
The map (object of class |
... |
Other parameters. |
som-class, SOM
require (datasets)
data (iris)
SOM (iris [, -5], 4, 4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.