Learn R Programming

fdm2id (version 1.0.1)

print.som: Print a self-organising map

Description

Prints the size of the map, how many of its units are actually used, and the dataset it was fitted on.

Usage

# S3 method for som
print(x, ...)

Arguments

x

The map (object of class som-class, created by SOM).

...

Other parameters.

See Also

som-class, SOM

Examples

Run this code
# \donttest{
require (datasets)
data (iris)
SOM (iris [, -5], 4, 4)
# }

Run the code above in your browser using DataLab