powered by
Prints the size of the map, how many of its units are actually used, and the dataset it was fitted on.
# S3 method for som print(x, ...)
The map (object of class som-class, created by SOM).
som-class
SOM
Other parameters.
som-class, SOM
# \donttest{ require (datasets) data (iris) SOM (iris [, -5], 4, 4) # }
Run the code above in your browser using DataLab