This class contains the model obtained by the SOM method.
Objects of this class are plain lists with the following components:
somAn object of class kohonen representing the fitted map.
nodesA vector of integer indicating the cluster to which each node is allocated.
clusterA vector of integer indicating the cluster to which each observation is allocated.
dataThe dataset that has been used to fit the map (as a matrix).
plot.som, SOM, som