This class contains the model obtained by Spectral clustering.
Objects of this class are plain lists with the following components:
clusterA vector of integer indicating the cluster to which each observation is allocated.
projThe projection of the dataset in the spectral space.
centersThe cluster centers (on the spectral space).
dataThe dataset that has been used to fit the model (as a matrix).
SPECTRAL, predict.spectral