Learn R Programming

fdm2id (version 1.0.1)

summary.model: Summary of a classification or regression model

Description

Prints the short description of print.model, followed by the summary of the wrapped model itself.

Usage

# S3 method for model
summary(object, ...)

Arguments

object

The model (object of class model-class).

...

Other parameters, passed to the summary of the wrapped model.

See Also

model-class, print.model

Examples

Run this code
require (datasets)
data (iris)
summary (NB (iris [, -5], iris [, 5]))

Run the code above in your browser using DataLab