powered by
Prints the short description of print.model, followed by the summary of the wrapped model itself.
print.model
# S3 method for model summary(object, ...)
The model (object of class model-class).
model-class
Other parameters, passed to the summary of the wrapped model.
model-class, print.model
require (datasets) data (iris) summary (NB (iris [, -5], iris [, 5]))
Run the code above in your browser using DataLab