| vectorizer-class | R Documentation |
This class contains a vectorization model for textual documents.
Objects of this class are plain lists with the following components:
vectorizerThe vectorizer.
transformThe transformation to be applied after vectorization (normalization, TF-IDF).
phrasesThe phrase detection method.
tfidfThe TF-IDF transformation.
lsaThe LSA transformation.
tokensThe token from the original document.
vectorize.docs, query.docs
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.